#.The objective of my project  was to estimate the sum of number of visits and the total of
#. expected_visiting_duration from the city of Wageningen with 9 zip codes (6701-6709)to 33 recreation
#.areas having a distance between 0.35 to 37.1 km from the city of Wageningen.
#.These results have been   obtained from my model ACRER and are stored on the Excel file


library(openxlsx)
library(pivottabler)
library(devtools)



fdata20 <- read.xlsx(
  "/Users/georgiosmartakis/Downloads/Statistics with R or Python/Statistics/pivottablesmodels3/data/import/fdata20.xlsx",sheet = 1,startRow = 1,colNames = TRUE,rowNames = FALSE,rows = NULL,cols = NULL)

Wageningen_crosstables <- createWorkbook(creator = "Georgios Martakis", title = "Wageningen_crosstables")

print("Sum of number of visits per location")
pt <- PivotTable$new()
pt$addData(fdata20)
pt$addRowDataGroups("recreation_areas",header = "recreation areas", totalCaption = "All_recreation_areas", styleDeclarations = list("color" = "white", "font-weight" = "bold","background-color" = "blue"))
pt$addColumnDataGroups("zip_code",totalCaption = "All_zip_codes", styleDeclarations = list("color" = "white", "font-weight" = "bold","background-color" = "blue"))
pt$defineCalculation(calculationName = "number_of_visits",summariseExpression = "sum(number_of_visits)",format = "%.1f")
pt$setRowDataGroupHeader(levelNumber = 1, header = "Recreation areas")
pt$renderPivot(exportOptions = list(skipNA = TRUE, skipNaN = TRUE), showRowGroupHeaders = TRUE)
addWorksheet(Wageningen_crosstables, "number_of_visits", gridLines = openxlsx_getOp("gridLines", TRUE))
pt$writeToExcelWorksheet(Wageningen_crosstables, wsName = "number_of_visits",topRowNumber = 1, leftMostColumnNumber = 1,outputValuesAs = "formattedValueAsNumber",outputHeadingsAs = "formattedValueAsText", applyStyles = TRUE, mapStylesFromCSS = TRUE)
saveWorkbook(Wageningen_crosstables, "/Users/georgiosmartakis/Downloads/Statistics with R or Python/Statistics/pivottablesmodels3/data/export/Wageningen_crosstables3.xlsx", overwrite = TRUE)
rm(pt)


print("calculate the total of expected_visiting_duration")
pt <- PivotTable$new()
pt$addData(fdata20)
pt$addRowDataGroups("recreation_areas",header = "recreation areas",totalCaption = "All_recreation_areas",
                    styleDeclarations = list("color" = "white", "font-weight" = "bold","background-color" = "blue"))
pt$addColumnDataGroups("zip_code",totalCaption = "All_zip_codes",
                       styleDeclarations = list("color" = "white", "font-weight" = "bold","background-color" = "blue"))
pt$defineCalculation(calculationName = "total_exp_visit_duration",
                     summariseExpression = "sum(expected_visiting_duration)",format = "%.1f")
pt$setRowDataGroupHeader(levelNumber = 1, header = "Recreation areas")
pt$renderPivot(exportOptions = list(skipNA = TRUE, skipNaN = TRUE),showRowGroupHeaders = TRUE)
addWorksheet(Wageningen_crosstables,"expected_visiting_duration")
pt$writeToExcelWorksheet(Wageningen_crosstables, wsName = "expected_visiting_duration",
topRowNumber = 1, leftMostColumnNumber = 1,outputValuesAs = "formattedValueAsNumber", applyStyles = TRUE, mapStylesFromCSS = TRUE)
saveWorkbook(Wageningen_crosstables, "/Users/georgiosmartakis/Downloads/Statistics with R or Python/Statistics/pivottablesmodels3/data/export/Wageningen_crosstables3.xlsx", overwrite = TRUE)
rm(pt)

print("total costs")
print("additional variables: distance, total fuel cost, total activities cost")
pt <- PivotTable$new()
pt$addData(fdata20)
pt$addRowDataGroups("recreation_areas",header = "recreation areas",totalCaption = "All_recreation_areas", styleDeclarations = list("color" = "white", "font-weight" = "bold","background-color" = "blue"))
pt$addColumnDataGroups("zip_code",totalCaption = "All_zip_codes", styleDeclarations = list("color" = "white", "font-weight" = "bold","background-color" = "blue"))
pt$defineCalculation(calculationName = "distances_km",summariseExpression = "mean(as.numeric(distances_km))", format = "%.2f")
pt$defineCalculation(calculationName = "total_fuel_cost", summariseExpression = "mean(as.numeric(fuel_cost_total))",format = "%.2f")
pt$defineCalculation(calculationName = "T_activ_costs",summariseExpression = "mean(as.numeric(total_activities_costs))",format = "%.2f ")
pt$defineCalculation(calculationName = "N_of_visits", summariseExpression = "sum(number_of_visits)", format = "%.2f")
pt$defineCalculation(calculationName = "visit_duration", summariseExpression = "sum(expected_visiting_duration)",format = "%.2f")
pt$renderPivot(exportOptions = list(skipNA = TRUE, skipNaN = TRUE),showRowGroupHeaders = TRUE)
addWorksheet(Wageningen_crosstables, "total_costs")
pt$writeToExcelWorksheet(Wageningen_crosstables, wsName = "total_costs",topRowNumber = 1, leftMostColumnNumber = 1,outputValuesAs = "formattedValueAsNumber",applyStyles = TRUE)
saveWorkbook(Wageningen_crosstables, "/Users/georgiosmartakis/Downloads/Statistics with R or Python/Statistics/pivottablesmodels3/data/export/Wageningen_crosstables3.xlsx", overwrite = TRUE)
rm(pt)

rm(Wageningen_crosstables)
